@@ -8,7 +8,6 @@ try:
 except ImportError:
     FLOWPLAYER_EXISTS = False
 
-
 class GetMediaShowItemView(BrowserView):
     """ Class that extracts relevant information for the slideshow
     """
@@ -119,6 +118,18 @@ class MediaShowListingView(BrowserView):
     """
     
     def getJSON(self):    
+        #--- Checking for recursive mode
+        if hasattr(self.request, 'recursive'):
+            recursive = self.request['recursive']
+        else:
+            recursive = "true"
+        
+        recursiveMode = False
+        
+        if recursive.find("true") != -1:
+            recursiveMode = True
+        #---
+        
         callback = hasattr(self.request, 'callback') and 'json' + self.request['callback'] or None
         jsonStr = ""
         
@@ -128,7 +139,7 @@ class MediaShowListingView(BrowserView):
         plone_utils = getToolByName(self.context, 'plone_utils')
         path = '/'.join(item.getPhysicalPath())
         
-        if item.portal_type == "Folder":
+        if item.portal_type == "Folder" or (item.restrictedTraverse('@@plone').isStructuralFolder()  and item.portal_type != "Topic"):
             results = catalog.searchResults(path = { 'query' : path, 'depth' : 1 }, sort_on = 'getObjPositionInParent')
         elif item.portal_type == "Topic":
             results = catalog.searchResults(item.getQuery())
@@ -140,7 +151,7 @@ class MediaShowListingView(BrowserView):
         
         #Python to JSON encoding
         for res in results:
-            if(self.getMediaURL(res.getObject()) != ""):
+            if self.getMediaURL(res.getObject()) != "":
                 resultArray.append({"url": res.getURL(), "UID": res["UID"]})
 
         jsonStr = json.dumps(resultArray)
@@ -164,7 +175,20 @@ class MediaShowListingView(BrowserView):
         
     def getMediaURL(self, item):
         """ finds and returns relevant leading media for the given item
-        """    
+        """
+        #--- Checking for recursive mode
+        if hasattr(self.request, 'recursive'):
+            recursive = self.request['recursive']
+        else:
+            recursive = "true"
+        
+        recursiveMode = False
+        
+        if recursive.find("true") != -1:
+            recursiveMode = True
+        
+        #---
+        
         if(self.isVideo(item)):
             return item.absolute_url()
             
@@ -173,25 +197,28 @@ class MediaShowListingView(BrowserView):
         
         if item.portal_type == 'Image':
             return item.absolute_url()
-            
-        catalog = getToolByName(self.context, 'portal_catalog')
-        plone_utils = getToolByName(self.context, 'plone_utils')
-        path = '/'.join(item.getPhysicalPath())
         
-        if plone_utils.isStructuralFolder(item):
-            results = catalog.searchResults(path = {'query' : path,'depth' : 1 }, type = ['Image', 'File', 'Link'], sort_on = 'getObjPositionInParent')
-            if len(results) > 0:
-                leadMedia = results[0]
-                if leadMedia.portal_type == 'Image':
-                    return leadMedia.getURL() + '/image_large'
-                elif leadMedia.portal_type == 'Link':
-                    return leadMedia.remoteUrl
+        if recursiveMode:   
+            catalog = getToolByName(self.context, 'portal_catalog')
+            plone_utils = getToolByName(self.context, 'plone_utils')
+            path = '/'.join(item.getPhysicalPath())
+            
+            if plone_utils.isStructuralFolder(item):
+                results = catalog.searchResults(path = {'query' : path,'depth' : 1 }, type = ['Image', 'File', 'Link'], sort_on = 'getObjPositionInParent')
+                if len(results) > 0:
+                    leadMedia = results[0]
+                    if leadMedia.portal_type == 'Image':
+                        return leadMedia.getURL() + '/image_large'
+                    elif leadMedia.portal_type == 'Link':
+                        return leadMedia.remoteUrl
+                    else:
+                        return leadMedia.getURL()
                 else:
-                    return leadMedia.getURL()
+                    return ""
             else:
+                #TODO: Add lead image support and News Item Image support
                 return ""
         else:
-            #TODO: Add lead image support and News Item Image support
             return ""
         
     def isVideo(self, item):
